# coding: utf-8


from __future__ import absolute_import

import re

# python 2 and python 3 compatibility library
import six

from authress_sdk.api_client import ApiClient


class AccountsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_account(self, account_id, **kwargs):
        """Get account information.

        Includes the original configuration information.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id: The unique identifier for the account (required)
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_account_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_account_with_http_info(account_id, **kwargs)
            return data

    def get_account_with_http_info(self, account_id, **kwargs):
        """Get account information.

        Includes the original configuration information.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_with_http_info(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str account_id: The unique identifier for the account (required)
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id`.")

        collection_formats = {}

        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/accounts/{accountId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Account',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_accounts(self, **kwargs):
        """Get all accounts user has access to

        Returns a list of accounts that the user has access to.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_accounts(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: AccountCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_accounts_with_http_info(**kwargs)
        else:
            (data) = self.get_accounts_with_http_info(**kwargs)
            return data

    def get_accounts_with_http_info(self, **kwargs):
        """Get all accounts user has access to

        Returns a list of accounts that the user has access to.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_accounts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: AccountCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_accounts" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/accounts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccountCollection',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_account_identities(self, **kwargs):
        """Get all linked identities for this account.

        Returns a list of identities linked for this account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_identities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IdentityCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_account_identities_with_http_info(**kwargs)
        else:
            (data) = self.get_account_identities_with_http_info(**kwargs)
            return data

    def get_account_identities_with_http_info(self, **kwargs):
        """Get all linked identities for this account.

        Returns a list of identities linked for this account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_account_identities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: IdentityCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_identities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/identities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IdentityCollection',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_identity(self, body, **kwargs):
        """Link a new account identity.

        An identity is a JWT subscriber *sub* and issuer *iss*. Only one account my be linked to a particular JWT combination. Allows calling the API with a federated token directly instead of using a client access key.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_identity(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdentityRequest body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_identity_with_http_info(body, **kwargs)
        else:
            (data) = self.create_identity_with_http_info(body, **kwargs)
            return data

    def create_identity_with_http_info(self, body, **kwargs):
        """Link a new account identity.

        An identity is a JWT subscriber *sub* and issuer *iss*. Only one account my be linked to a particular JWT combination. Allows calling the API with a federated token directly instead of using a client access key.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_identity_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdentityRequest body: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_identity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body`.")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json'])



        return self.api_client.call_api(
            '/v1/identities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8


import pprint
import re

import six


class IdentityRequest(object):

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'jwt': 'str',
        'preferred_audience': 'str'
    }

    attribute_map = {
        'jwt': 'jwt',
        'preferred_audience': 'preferredAudience'
    }

    def __init__(self, jwt=None, preferred_audience=None):
        """IdentityRequest"""
        self._jwt = None
        self._preferred_audience = None
        self.discriminator = None
        self.jwt = jwt
        if preferred_audience is not None:
            self.preferred_audience = preferred_audience

    @property
    def jwt(self):
        """Gets the jwt of this IdentityRequest.

        A valid JWT OIDC compliant token which will still pass authentication requests to the identity provider. Must contain a unique audience and issuer.

        :return: The jwt of this IdentityRequest.
        :rtype: str
        """
        return self._jwt

    @jwt.setter
    def jwt(self, jwt):
        """Sets the jwt of this IdentityRequest.

        A valid JWT OIDC compliant token which will still pass authentication requests to the identity provider. Must contain a unique audience and issuer.

        :param jwt: The jwt of this IdentityRequest.
        :type: str
        """
        if jwt is None:
            raise ValueError("Invalid value for `jwt`, must not be `None`")

        self._jwt = jwt

    @property
    def preferred_audience(self):
        """Gets the preferred_audience of this IdentityRequest.

        If the `jwt` token contains more than one valid audience, then the single audience that should associated with Authress. If more than one audience is preferred, repeat this call with each one.

        :return: The preferred_audience of this IdentityRequest.
        :rtype: str
        """
        return self._preferred_audience

    @preferred_audience.setter
    def preferred_audience(self, preferred_audience):
        """Sets the preferred_audience of this IdentityRequest.

        If the `jwt` token contains more than one valid audience, then the single audience that should associated with Authress. If more than one audience is preferred, repeat this call with each one.

        :param preferred_audience: The preferred_audience of this IdentityRequest.
        :type: str
        """

        self._preferred_audience = preferred_audience

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdentityRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8


import pprint
import re

import six


class ClientAccessKey(object):

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_id': 'str',
        'client_id': 'str',
        'generation_date': 'datetime',
        'access_key': 'str'
    }

    attribute_map = {
        'key_id': 'keyId',
        'client_id': 'clientId',
        'generation_date': 'generationDate',
        'access_key': 'accessKey'
    }

    def __init__(self, key_id=None, client_id=None, generation_date=None, access_key=None):
        """ClientAccessKey"""
        self._key_id = None
        self._client_id = None
        self._generation_date = None
        self._access_key = None
        self.discriminator = None
        if key_id is not None:
            self.key_id = key_id
        self.client_id = client_id
        if generation_date is not None:
            self.generation_date = generation_date
        if access_key is not None:
            self.access_key = access_key

    @property
    def key_id(self):
        """Gets the key_id of this ClientAccessKey.

        The unique id of the client.

        :return: The key_id of this ClientAccessKey.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """Sets the key_id of this ClientAccessKey.

        The unique id of the client.

        :param key_id: The key_id of this ClientAccessKey.
        :type: str
        """

        self._key_id = key_id

    @property
    def client_id(self):
        """Gets the client_id of this ClientAccessKey.

        The unique id of the client.

        :return: The client_id of this ClientAccessKey.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this ClientAccessKey.

        The unique id of the client.

        :param client_id: The client_id of this ClientAccessKey.
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")

        self._client_id = client_id

    @property
    def generation_date(self):
        """Gets the generation_date of this ClientAccessKey.


        :return: The generation_date of this ClientAccessKey.
        :rtype: datetime
        """
        return self._generation_date

    @generation_date.setter
    def generation_date(self, generation_date):
        """Sets the generation_date of this ClientAccessKey.


        :param generation_date: The generation_date of this ClientAccessKey.
        :type: datetime
        """

        self._generation_date = generation_date

    @property
    def access_key(self):
        """Gets the access_key of this ClientAccessKey.

        An encoded access key which contains identifying information for client access token creation. For direct use with the Authress SDKs, not meant to be decoded. Must be saved on created, as it will never be returned from the API ever again. Authress only saved the corresponding public key to verify private access keys.

        :return: The access_key of this ClientAccessKey.
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this ClientAccessKey.

        An encoded access key which contains identifying information for client access token creation. For direct use with the Authress SDKs, not meant to be decoded. Must be saved on created, as it will never be returned from the API ever again. Authress only saved the corresponding public key to verify private access keys.

        :param access_key: The access_key of this ClientAccessKey.
        :type: str
        """

        self._access_key = access_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClientAccessKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientAccessKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8


from __future__ import absolute_import

import re

# python 2 and python 3 compatibility library
import six

from authress_sdk.api_client import ApiClient


class UserPermissionsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_user_resources(self, user_id, **kwargs):
        """Get the resources a user has to permission to.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Get most conservative resource permission a user has access to. Since resource uris are cascading, a user with * access will always return a list with a single result. In the case that the user only has access to a list of resources in a collection, the list will be paginated.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_resources(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on, if not specified will use the token sub as the expected user to authorize
        :param str resource_uri: The top level uri path of a resource to query for. Will only match explicit or collection resource children. Will not partial match resource names.
        :return: UserResources
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if user_id is None:
          user_id = self.api_client.get_user_from_token()

        if kwargs.get('async_req'):
            return self.get_user_resources_with_http_info(user_id, **kwargs)
        else:
            (data) = self.get_user_resources_with_http_info(user_id, **kwargs)
            return data

    def get_user_resources_with_http_info(self, user_id, **kwargs):
        """Get the resources a user has to permission to.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Get most conservative resource permission a user has access to. Since resource uris are cascading, a user with * access will always return a list with a single result. In the case that the user only has access to a list of resources in a collection, the list will be paginated.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_resources_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on (required)
        :param str resource_uri: The top level uri path of a resource to query for. Will only match explicit or collection resource children. Will not partial match resource names.
        :return: UserResources
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'resource_uri']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id`.")

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']

        query_params = []
        if 'resource_uri' in params:
            query_params.append(('resourceUri', params['resource_uri']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/users/{userId}/resources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResources',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_authorization_for_resource (self, user_id, resource_uri, **kwargs):
        """Get the permissions a user has to a resource.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Get a summary of the permissions a user has to a particular resource.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_authorization_for_resource(user_id, resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on, if not specified will use the token sub as the expected user to authorize
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: UserPermissions
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True

        if user_id is None:
          user_id = self.api_client.get_user_from_token()

        if kwargs.get('async_req'):
            return self.get_user_authorization_for_resource_with_http_info(user_id, resource_uri, **kwargs)
        else:
            (data) = self.get_user_authorization_for_resource_with_http_info(user_id, resource_uri, **kwargs)
            return data

    def get_user_authorization_for_resource_with_http_info(self, user_id, resource_uri, **kwargs):
        """Get the permissions a user has to a resource.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Get a summary of the permissions a user has to a particular resource.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_authorization_for_resource_with_http_info(user_id, resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on (required)
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: UserPermissions
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'resource_uri']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_authorization_for_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id`.")
        # verify the required parameter 'resource_uri' is set
        if ('resource_uri' not in params or
                params['resource_uri'] is None):
            raise ValueError("Missing the required parameter `resource_uri`.")

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'resource_uri' in params:
            path_params['resourceUri'] = params['resource_uri']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/users/{userId}/resources/{resourceUri}/permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserPermissions',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def authorize_user(self, user_id, resource_uri, permission, **kwargs):
        """Check to see if a user has permissions to a resource.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Does the user have the specified permissions to the resource?
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authorize_user(user_id, resource_uri, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on, if not specified will use the token sub as the expected user to authorize
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed, the resource must be a full path, and permissions are not inherited by sub resources. (required)
        :param str permission: Permission to check, '*' and scoped permissions can also be checked here. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if user_id is None:
          user_id = self.api_client.get_user_from_token()

        if kwargs.get('async_req'):
            return self.authorize_user_with_http_info(user_id, resource_uri, permission, **kwargs)
        else:
            (data) = self.authorize_user_with_http_info(user_id, resource_uri, permission, **kwargs)
            return data

    def authorize_user_with_http_info(self, user_id, resource_uri, permission, **kwargs):
        """Check to see if a user has permissions to a resource.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Does the user have the specified permissions to the resource?
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.authorize_user_with_http_info(user_id, resource_uri, permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The user to check permissions on (required)
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed, the resource must be a full path, and permissions are not inherited by sub resources. (required)
        :param str permission: Permission to check, '*' and scoped permissions can also be checked here. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'resource_uri', 'permission']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method authorize_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id`.")
        # verify the required parameter 'resource_uri' is set
        if ('resource_uri' not in params or
                params['resource_uri'] is None):
            raise ValueError("Missing the required parameter `resource_uri`.")
        # verify the required parameter 'permission' is set
        if ('permission' not in params or
                params['permission'] is None):
            raise ValueError("Missing the required parameter `permission`.")

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'resource_uri' in params:
            path_params['resourceUri'] = params['resource_uri']
        if 'permission' in params:
            path_params['permission'] = params['permission']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(['application/links+json'])

        return self.api_client.call_api(
            '/v1/users/{userId}/resources/{resourceUri}/permissions/{permission}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8


from __future__ import absolute_import

import re

# python 2 and python 3 compatibility library
import six

from authress_sdk.api_client import ApiClient


class AccessRecordsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_claim(self, body, **kwargs):
        """Claim a resource by an allowed user

        Claim a resource by allowing a user to pick an identifier and receive admin access to that resource if it hasn't already been claimed. This only works for resources specifically marked as <strong>CLAIM</strong>. The result will be a new access record listing that user as the admin for this resource.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_claim(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ClaimRequest body: (required)
        :return: ClaimResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_claim_with_http_info(body, **kwargs)
        else:
            (data) = self.create_claim_with_http_info(body, **kwargs)
            return data

    def create_claim_with_http_info(self, body, **kwargs):
        """Claim a resource by an allowed user

        Claim a resource by allowing a user to pick an identifier and receive admin access to that resource if it hasn't already been claimed. This only works for resources specifically marked as <strong>CLAIM</strong>. The result will be a new access record listing that user as the admin for this resource.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_claim_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ClaimRequest body: (required)
        :return: ClaimResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_claim" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body`.")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json'])



        return self.api_client.call_api(
            '/v1/claims', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ClaimResponse',
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_records(self, **kwargs):
        """Get all account records.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Returns a paginated records list for the account. Only records the user has access to are returned.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_records(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: AccessRecordCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_records_with_http_info(**kwargs)
        else:
            (data) = self.get_records_with_http_info(**kwargs)
            return data

    def get_records_with_http_info(self, **kwargs):
        """Get all account records.

        <i class=\"far fa-money-bill-alt text-primary\"></i> <span class=\"text-primary\">Billable</span> Returns a paginated records list for the account. Only records the user has access to are returned.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_records_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: AccessRecordCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_records" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/records', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccessRecordCollection',
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_record(self, body, **kwargs):
        """Create a new access record

        Specify user roles for specific resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_record(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessRecord body: (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_record_with_http_info(body, **kwargs)
        else:
            (data) = self.create_record_with_http_info(body, **kwargs)
            return data

    def create_record_with_http_info(self, body, **kwargs):
        """Create a new access record

        Specify user roles for specific resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_record_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessRecord body: (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_record" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body`.")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json'])



        return self.api_client.call_api(
            '/v1/records', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccessRecord',
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_record(self, record_id, **kwargs):
        """Deletes an access record.

        Remove an access record, removing associated permissions from all users in record. If a user has a permission from another record, that permission will not be removed.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_record(record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str record_id: The identifier of the access record. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_record_with_http_info(record_id, **kwargs)
        else:
            (data) = self.delete_record_with_http_info(record_id, **kwargs)
            return data

    def delete_record_with_http_info(self, record_id, **kwargs):
        """Deletes an access record.

        Remove an access record, removing associated permissions from all users in record. If a user has a permission from another record, that permission will not be removed.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_record_with_http_info(record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str record_id: The identifier of the access record. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['record_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_record" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'record_id' is set
        if ('record_id' not in params or
                params['record_id'] is None):
            raise ValueError("Missing the required parameter `record_id`.")

        collection_formats = {}

        path_params = {}
        if 'record_id' in params:
            path_params['recordId'] = params['record_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None


        return self.api_client.call_api(
            '/v1/records/{recordId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_record(self, record_id, **kwargs):
        """Get an access record for the account.

        Access records contain information assigning permissions to users for resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_record(record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str record_id: The identifier of the access record. (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_record_with_http_info(record_id, **kwargs)
        else:
            (data) = self.get_record_with_http_info(record_id, **kwargs)
            return data

    def get_record_with_http_info(self, record_id, **kwargs):
        """Get an access record for the account.

        Access records contain information assigning permissions to users for resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_record_with_http_info(record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str record_id: The identifier of the access record. (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['record_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_record" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'record_id' is set
        if ('record_id' not in params or
                params['record_id'] is None):
            raise ValueError("Missing the required parameter `record_id`.")

        collection_formats = {}

        path_params = {}
        if 'record_id' in params:
            path_params['recordId'] = params['record_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/records/{recordId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccessRecord',
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_record(self, body, record_id, **kwargs):
        """Update an access record.

        Updates an access record adding or removing user permissions to resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_record(body, record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessRecord body: (required)
        :param str record_id: The identifier of the access record. (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_record_with_http_info(body, record_id, **kwargs)
        else:
            (data) = self.update_record_with_http_info(body, record_id, **kwargs)
            return data

    def update_record_with_http_info(self, body, record_id, **kwargs):
        """Update an access record.

        Updates an access record adding or removing user permissions to resources.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_record_with_http_info(body, record_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AccessRecord body: (required)
        :param str record_id: The identifier of the access record. (required)
        :return: AccessRecord
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'record_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_record" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body`.")
        # verify the required parameter 'record_id' is set
        if ('record_id' not in params or
                params['record_id'] is None):
            raise ValueError("Missing the required parameter `record_id`.")

        collection_formats = {}

        path_params = {}
        if 'record_id' in params:
            path_params['recordId'] = params['record_id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json'])



        return self.api_client.call_api(
            '/v1/records/{recordId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccessRecord',
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from authress_sdk.api.access_records_api import AccessRecordsApi
from authress_sdk.api.accounts_api import AccountsApi
from authress_sdk.api.resource_permissions_api import ResourcePermissionsApi
from authress_sdk.api.service_clients_api import ServiceClientsApi
from authress_sdk.api.user_permissions_api import UserPermissionsApi



# coding: utf-8


import pprint
import re

import six


class ClaimRequest(object):

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'collection_resource': 'str',
        'resource_id': 'str'
    }

    attribute_map = {
        'collection_resource': 'collectionResource',
        'resource_id': 'resourceId'
    }

    def __init__(self, collection_resource=None, resource_id=None):
        """ClaimRequest"""
        self._collection_resource = None
        self._resource_id = None
        self.discriminator = None
        self.collection_resource = collection_resource
        self.resource_id = resource_id

    @property
    def collection_resource(self):
        """Gets the collection_resource of this ClaimRequest.

        The parent resource to add a child resource to. The resource must have a resource configuration that add the permission CLAIM for this to work.

        :return: The collection_resource of this ClaimRequest.
        :rtype: str
        """
        return self._collection_resource

    @collection_resource.setter
    def collection_resource(self, collection_resource):
        """Sets the collection_resource of this ClaimRequest.

        The parent resource to add a child resource to. The resource must have a resource configuration that add the permission CLAIM for this to work.

        :param collection_resource: The collection_resource of this ClaimRequest.
        :type: str
        """
        if collection_resource is None:
            raise ValueError("Invalid value for `collection_resource`, must not be `None`")

        self._collection_resource = collection_resource

    @property
    def resource_id(self):
        """Gets the resource_id of this ClaimRequest.

        The child resource the user is requesting Admin ownership over.

        :return: The resource_id of this ClaimRequest.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this ClaimRequest.

        The child resource the user is requesting Admin ownership over.

        :param resource_id: The resource_id of this ClaimRequest.
        :type: str
        """
        if resource_id is None:
            raise ValueError("Invalid value for `resource_id`, must not be `None`")

        self._resource_id = resource_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClaimRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClaimRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import os
from setuptools import setup, find_packages

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "PyJWT >= 2.0.0", "cryptography >= 2.9.2"]

# To install the library, run the following
#
# python setup.py install

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
  long_description = f.read()

with open(os.path.join(this_directory, 'authress_sdk', 'VERSION')) as version_file:
  VERSION = version_file.read().strip()

print("Building version", VERSION)

setup(
  name = 'authress-sdk',
  version = VERSION,
  description = 'Authress SDK for authorization as a service and interact with the Authress API.',
  author = 'Rhosys Developers',
  author_email = 'developers@authress.io',
  url = 'https://github.com/Authress/authress-sdk.py.git',
  include_package_data = True,
  install_requires=REQUIRES,
  packages = find_packages(exclude=['tests']),
  data_files=[('', ['authress_sdk/VERSION'])],
  keywords = ['Authorization as a service', 'Security', 'authorization', 'authorization as a service', 'authentication', 'user authentication', 'Authress', 'Authress client', 'access management', 'access management as a service', 'user security', 'oso', 'polar', 'open source policy engine', 'embedded authorization', 'batteries included authorization'],
  classifiers = [],
  license = 'Apache-2.0',
  long_description=long_description,
  long_description_content_type='text/markdown'
)



# coding: utf-8


from __future__ import absolute_import

import re

# python 2 and python 3 compatibility library
import six

from authress_sdk.api_client import ApiClient


class ResourcePermissionsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_resources(self, **kwargs):
        """List resource configurations

        Permissions can be set globally at a resource level. Lists any resources with a globally set resource policy
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResourcePermissionCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_resources_with_http_info(**kwargs)
        else:
            (data) = self.get_resources_with_http_info(**kwargs)
            return data

    def get_resources_with_http_info(self, **kwargs):
        """List resource configurations

        Permissions can be set globally at a resource level. Lists any resources with a globally set resource policy
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ResourcePermissionCollection
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_resources" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/resources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourcePermissionCollection',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_resource_permissions(self, resource_uri, **kwargs):
        """Get a resource permissions object.

        Permissions can be set globally at a resource level. This will apply to all users in an account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resource_permissions(resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: ResourcePermission
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_resource_permissions_with_http_info(resource_uri, **kwargs)
        else:
            (data) = self.get_resource_permissions_with_http_info(resource_uri, **kwargs)
            return data

    def get_resource_permissions_with_http_info(self, resource_uri, **kwargs):
        """Get a resource permissions object.

        Permissions can be set globally at a resource level. This will apply to all users in an account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resource_permissions_with_http_info(resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: ResourcePermission
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_uri']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_resource_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'resource_uri' is set
        if ('resource_uri' not in params or
                params['resource_uri'] is None):
            raise ValueError("Missing the required parameter `resource_uri`.")

        collection_formats = {}

        path_params = {}
        if 'resource_uri' in params:
            path_params['resourceUri'] = params['resource_uri']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])



        return self.api_client.call_api(
            '/v1/resources/{resourceUri}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourcePermission',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_resource_permissions(self, body, resource_uri, **kwargs):
        """Update a resource permissions object.

        Updates the global permissions on a resource. This applies to all users in an account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_resource_permissions(body, resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourcePermission body: The contents of the permission to set on the resource. Overwrites existing data. (required)
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_resource_permissions_with_http_info(body, resource_uri, **kwargs)
        else:
            (data) = self.set_resource_permissions_with_http_info(body, resource_uri, **kwargs)
            return data

    def set_resource_permissions_with_http_info(self, body, resource_uri, **kwargs):
        """Update a resource permissions object.

        Updates the global permissions on a resource. This applies to all users in an account.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_resource_permissions_with_http_info(body, resource_uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourcePermission body: The contents of the permission to set on the resource. Overwrites existing data. (required)
        :param str resource_uri: The uri path of a resource to validate, uri segments are allowed. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'resource_uri']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_resource_permissions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body`.")
        # verify the required parameter 'resource_uri' is set
        if ('resource_uri' not in params or
                params['resource_uri'] is None):
            raise ValueError("Missing the required parameter `resource_uri`.")

        collection_formats = {}

        path_params = {}
        if 'resource_uri' in params:
            path_params['resourceUri'] = params['resource_uri']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/links+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json'])



        return self.api_client.call_api(
            '/v1/resources/{resourceUri}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',

            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
